multivitamin.applications.images.classifiers package
====================================================

Submodules
----------

multivitamin.applications.images.classifiers.caffe\_classifier module
---------------------------------------------------------------------

.. automodule:: multivitamin.applications.images.classifiers.caffe_classifier
   :members:
   :undoc-members:
   :show-inheritance:

multivitamin.applications.images.classifiers.pyt\_classifier module
-------------------------------------------------------------------

.. automodule:: multivitamin.applications.images.classifiers.pyt_classifier
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: multivitamin.applications.images.classifiers
   :members:
   :undoc-members:
   :show-inheritance:
